@@ -9,6 +9,14 @@ class Settings(object):
     .. attribute:: DEFAULT_KEYPREFIX
     
         The prefix to prepend to all keys. Default ``"stdnet"``.
+        
+    .. attribute:: SCHEMA
+    
+        This defines how instances of models are stored on the back-end server.
+        It is only used when a Redis back-end server is used. Possible choices::
+        
+            * hash
+            * compact-hash (default)
                 
 To change settings::
     
@@ -19,6 +27,7 @@ To change settings::
     def __init__(self):
         self.DEFAULT_BACKEND    = 'redis://127.0.0.1:6379/?db=7'
         self.DEFAULT_KEYPREFIX  = 'stdnet.'
+        self.SCHEMA = 'compact-hash'
         
         
 settings = Settings()
