@@ -28,6 +28,8 @@ __all__ = ['Field',
            'PickleObjectField',
            'ModelField']
 
+EMPTY = ''
+
 
 class Field(UnicodeMixin):
     '''This is the base class of all StdNet Fields.
@@ -224,7 +226,7 @@ class IntegerField(AtomField):
     '''An integer :class:`AtomField`.'''
     type = 'integer'
     default = 0
-    def serialise(self, value):
+    def serialize(self, value):
         if value is not None:
             try:
                 return int(value)
@@ -233,7 +235,8 @@ class IntegerField(AtomField):
         return value
     
     def to_python(self, value):
-        if value:
+        '''Convert ``value`` to an integer if possible.'''
+        if value is not None and value is not EMPTY:
             return int(value)
         else:
             return self.default
@@ -243,7 +246,11 @@ class IntegerField(AtomField):
 class BooleanField(AtomField):
     '''An boolean :class:`AtomField`'''
     type = 'bool'
-    def serialise(self, value):
+    
+    def __init__(self, required = False, **kwargs):
+        super(BooleanField,self).__init__(required = required,**kwargs)
+                 
+    def serialize(self, value):
         return True if value else False
         
     def to_python(self, value):
@@ -263,7 +270,7 @@ if you don't specify otherwise.
     def serialize(self, value):
         if not value:
             value = self.meta.cursor.incr(self.meta.autoid())
-        return super(AutoField,self).serialise(value)
+        return super(AutoField,self).serialize(value)
 
 
 class FloatField(AtomField):
@@ -412,7 +419,8 @@ class JSONField(CharField):
         super(JSONField,self).__init__(*args, **kwargs)
         
     def to_python(self, value):
-        if is_string(value):
+        if value is not None:
+            value = to_string(value)
             if not value:
                 value = {}
             else:
